==> knative-model-6.4.1-sources.jar: io/fabric8/knative/serving/v1beta1/DomainMappingListFluent.java <==
package io.fabric8.knative.serving.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface DomainMappingListFluent<A extends DomainMappingListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(Integer index,DomainMapping item);
  public A setToItems(Integer index,DomainMapping item);
  public A addToItems(io.fabric8.knative.serving.v1beta1.DomainMapping... items);
  public A addAllToItems(Collection<DomainMapping> items);
  public A removeFromItems(io.fabric8.knative.serving.v1beta1.DomainMapping... items);
  public A removeAllFromItems(Collection<DomainMapping> items);
  public A removeMatchingFromItems(Predicate<DomainMappingBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<DomainMapping> getItems();
  public List<DomainMapping> buildItems();
  public DomainMapping buildItem(Integer index);
  public DomainMapping buildFirstItem();
  public DomainMapping buildLastItem();
  public DomainMapping buildMatchingItem(Predicate<DomainMappingBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<DomainMappingBuilder> predicate);
  public A withItems(List<DomainMapping> items);
  public A withItems(io.fabric8.knative.serving.v1beta1.DomainMapping... items);
  public Boolean hasItems();
  public DomainMappingListFluent.ItemsNested<A> addNewItem();
  public DomainMappingListFluent.ItemsNested<A> addNewItemLike(DomainMapping item);
  public DomainMappingListFluent.ItemsNested<A> setNewItemLike(Integer index,DomainMapping item);
  public DomainMappingListFluent.ItemsNested<A> editItem(Integer index);
  public DomainMappingListFluent.ItemsNested<A> editFirstItem();
  public DomainMappingListFluent.ItemsNested<A> editLastItem();
  public DomainMappingListFluent.ItemsNested<A> editMatchingItem(Predicate<DomainMappingBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,DomainMappingFluent<DomainMappingListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}

==> knative-model-6.7.1-sources.jar: io/fabric8/knative/serving/v1beta1/DomainMappingListFluent.java <==
package io.fabric8.knative.serving.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface DomainMappingListFluent<A extends DomainMappingListFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public A addToItems(int index,DomainMapping item);
  public A setToItems(int index,DomainMapping item);
  public A addToItems(io.fabric8.knative.serving.v1beta1.DomainMapping... items);
  public A addAllToItems(Collection<DomainMapping> items);
  public A removeFromItems(io.fabric8.knative.serving.v1beta1.DomainMapping... items);
  public A removeAllFromItems(Collection<DomainMapping> items);
  public A removeMatchingFromItems(Predicate<DomainMappingBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildItems instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<DomainMapping> getItems();
  public List<DomainMapping> buildItems();
  public DomainMapping buildItem(int index);
  public DomainMapping buildFirstItem();
  public DomainMapping buildLastItem();
  public DomainMapping buildMatchingItem(Predicate<DomainMappingBuilder> predicate);
  public Boolean hasMatchingItem(Predicate<DomainMappingBuilder> predicate);
  public A withItems(List<DomainMapping> items);
  public A withItems(io.fabric8.knative.serving.v1beta1.DomainMapping... items);
  public Boolean hasItems();
  public DomainMappingListFluent.ItemsNested<A> addNewItem();
  public DomainMappingListFluent.ItemsNested<A> addNewItemLike(DomainMapping item);
  public DomainMappingListFluent.ItemsNested<A> setNewItemLike(int index,DomainMapping item);
  public DomainMappingListFluent.ItemsNested<A> editItem(int index);
  public DomainMappingListFluent.ItemsNested<A> editFirstItem();
  public DomainMappingListFluent.ItemsNested<A> editLastItem();
  public DomainMappingListFluent.ItemsNested<A> editMatchingItem(Predicate<DomainMappingBuilder> predicate);
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  public ListMeta getMetadata();
  public A withMetadata(ListMeta metadata);
  public Boolean hasMetadata();
  public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
  public interface ItemsNested<N> extends Nested<N>,DomainMappingFluent<DomainMappingListFluent.ItemsNested<N>>{
    public N and();
    public N endItem();
    
  }
  
}
